############### Goedert et al - Frog Color: ###############
# Goedert, D., Clement, D., Calsbeek, R. Evolutionary trade-offs may interact with physiological constraints to maintain color variation. Ecological Monographs.
#################################################
########## Goedert et al - Rscript Pictures - Sex Diffs ###########
## Created by: D. Goedert, modified 2020-05-18: 
## same analyses as other script, but not removing ponds with low sample sizes
#################################################
############### Chapter 2- Frog Color: ###############
setwd("drag and drop Codes-Pictures folder in here")
### Note: actually replace everything in between " " for the file path to the Dryad folder.
inputpath<-"./DataSets"
#################################################
data<-read.csv(paste(inputpath, "Color_norecap.csv", sep="/"))[,-1]
str(data)
# 'data.frame':	514 obs. of  11 variables:
 # $ FullID : Factor w/ 514 levels "2016-CEF1","2016-CEF2",..: 1 2 3 4 5 6 7 8 9 10 ...
 # $ Rs     : num  71.1 70.2 103.2 59.2 110.5 ...
 # $ Gs     : num  70.2 67.1 84.9 60.7 77.8 ...
 # $ Bs     : num  60.1 56.5 66.7 51.1 58.8 ...
 # $ h      : num  0.1536 0.1289 0.0828 0.1924 0.0612 ...
 # $ s      : num  0.155 0.196 0.354 0.157 0.468 ...
 # $ v      : num  0.279 0.275 0.405 0.238 0.433 ...
 # $ Year   : int  2016 2016 2016 2016 2016 2016 2016 2016 2016 2016 ...
 # $ Pop    : Factor w/ 10 levels "CE","CM","CW",..: 1 1 1 1 1 1 1 1 2 2 ...
 # $ Sex    : Factor w/ 2 levels "F","M": 1 1 1 1 1 1 2 2 1 2 ...
 # $ pc1_rgb: num  -10.3 -13.6 25.3 -27.3 25.7 ...
############################################################
tapply(data$FullID, data$Year, length)
# 2016 2017 
 # 225  289 
tapply(data$FullID, data$Pop, length)
  # CE   CM   CW Farm   Gr Land   LG   MB   NC  Ray 
  # 22   10   62   65   76    3   74   54   71   77 
############################################################
data.frame(cbind(tapply(data$Pop[data$Year=="2016"], data$Pop[data$Year=="2016"], length), tapply(data$Pop[data$Year=="2017"], data$Pop[data$Year=="2017"], length)))
     # X1 X2
# CE    8 14
# CM    7  3
# CW   27 35
# Farm 34 31
# Gr   42 34
# Land  3 NA
# LG   28 46
# MB   21 33
# NC   27 44
# Ray  28 49
#################################################
library(vegan)
############################################################
################ ANALYSIS SEX DIFFERENCES: ################
############################################################
set.seed(1234)
adonis(data[,5:7]~Sex*Year*Pop, data=data)
# Call:
# adonis(formula = data[, 5:7] ~ Sex * Year * Pop, data = data) 

# Permutation: free
# Number of permutations: 999

# Terms added sequentially (first to last)

              # Df SumsOfSqs MeanSqs F.Model      R2 Pr(>F)    
# Sex            1    0.5480 0.54799  34.604 0.04968  0.001 ***
# Year           1    1.8985 1.89854 119.887 0.17213  0.001 ***
# Pop            9    0.2832 0.03147   1.987 0.02568  0.033 *  
# Sex:Year       1    0.0714 0.07141   4.509 0.00647  0.025 *  
# Sex:Pop        8    0.2118 0.02648   1.672 0.01921  0.069 .  
# Year:Pop       8    0.2524 0.03155   1.992 0.02288  0.043 *  
# Sex:Year:Pop   6    0.1790 0.02983   1.884 0.01623  0.071 .  
# Residuals    479    7.5855 0.01584         0.68772           
# Total        513   11.0298                 1.00000           
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

###########################################################
###### posthocs: Year and Pop with grouping factor
#################################################
set.seed(1234)
adonis(data[,5:7]~Sex*Year, data,strata=data$Pop)
# Call:
# adonis(formula = data[, 5:7] ~ Sex * Year, data = data, strata = data$Pop) 

# Blocks:  strata 
# Permutation: free
# Number of permutations: 999

# Terms added sequentially (first to last)

           # Df SumsOfSqs MeanSqs F.Model      R2 Pr(>F)    
# Sex         1    0.5480 0.54799  32.858 0.04968  0.001 ***
# Year        1    1.8985 1.89854 113.840 0.17213  0.001 ***
# Sex:Year    1    0.0779 0.07793   4.673 0.00707  0.033 *  
# Residuals 510    8.5054 0.01668         0.77112           
# Total     513   11.0298                 1.00000           
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

set.seed(1234)
adonis(data[,5:7]~Sex*Pop, data=data, strata=data$Year)
# Call:
# adonis(formula = data[, 5:7] ~ Sex * Pop, data = data, strata = data$Year) 

# Blocks:  strata 
# Permutation: free
# Number of permutations: 999

# Terms added sequentially (first to last)

           # Df SumsOfSqs MeanSqs F.Model      R2 Pr(>F)    
# Sex         1    0.5480 0.54799 27.6161 0.04968  0.001 ***
# Pop         9    0.3390 0.03767  1.8984 0.03074  0.094 .  
# Sex:Pop     8    0.3205 0.04006  2.0191 0.02906  0.065 .  
# Residuals 495    9.8223 0.01984         0.89052           
# Total     513   11.0298                 1.00000           
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

#################################################
###### posthocs: differences male and female within each year:
#################################################
set.seed(1234)
adonis(data[data$Sex=="M",5:7]~Year, data=data[data$Sex=="M",], strata=data$Pop[data$Sex=="M"])
# Call:
# adonis(formula = data[data$Sex == "M", 5:7] ~ Year, data = data[data$Sex ==      "M", ], strata = data$Pop[data$Sex == "M"]) 

# Blocks:  strata 
# Permutation: free
# Number of permutations: 999

# Terms added sequentially (first to last)

           # Df SumsOfSqs MeanSqs F.Model      R2 Pr(>F)    
# Year        1    1.7497 1.74968  106.42 0.21308  0.001 ***
# Residuals 393    6.4616 0.01644         0.78692           
# Total     394    8.2112                 1.00000           
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

set.seed(1234)
adonis(data[data$Sex=="F",5:7]~Year, data=data[data$Sex=="F",], strata=data$Pop[data$Sex=="F"])
# Call:
# adonis(formula = data[data$Sex == "F", 5:7] ~ Year, data = data[data$Sex ==      "F", ], strata = data$Pop[data$Sex == "F"]) 

# Blocks:  strata 
# Permutation: free
# Number of permutations: 999

# Terms added sequentially (first to last)

           # Df SumsOfSqs  MeanSqs F.Model      R2 Pr(>F)    
# Year        1   0.22679 0.226789  12.983 0.09988  0.001 ***
# Residuals 117   2.04383 0.017469         0.90012           
# Total     118   2.27062                  1.00000           
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1  

set.seed(1234)
adonis(data[data$Year=="2016",5:7]~Sex, data=data[data$Year=="2016",], strata=data$Pop[data$Year=="2016"])
# Call:
# adonis(formula = data[data$Year == "2016", 5:7] ~ Sex, data = data[data$Year ==      "2016", ], strata = data$Pop[data$Year == "2016"]) 

# Blocks:  strata 
# Permutation: free
# Number of permutations: 999

# Terms added sequentially (first to last)

           # Df SumsOfSqs MeanSqs F.Model      R2 Pr(>F)    
# Sex         1    0.8603 0.86025  41.235 0.15605  0.001 ***
# Residuals 223    4.6523 0.02086         0.84395           
# Total     224    5.5126                 1.00000           
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

set.seed(1234)
adonis(data[data$Year=="2017",5:7]~Sex, data=data[data$Year=="2017",], strata=data$Pop[data$Year=="2017"])
# Call:
# adonis(formula = data[data$Year == "2017", 5:7] ~ Sex, data = data[data$Year ==      "2017", ], strata = data$Pop[data$Year == "2017"]) 

# Blocks:  strata 
# Permutation: free
# Number of permutations: 999

# Terms added sequentially (first to last)

           # Df SumsOfSqs  MeanSqs F.Model      R2 Pr(>F)    
# Sex         1    0.2698 0.269827  20.098 0.06545  0.001 ***
# Residuals 287    3.8531 0.013425         0.93455           
# Total     288    4.1229                  1.00000           
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
############################################################
############################################################
# betadisper
# Implements Marti Anderson's PERMDISP2 procedure for the analysis of multivariate homogeneity of group dispersions (variances). betadisper is a multivariate analogue of Levene's test for homogeneity of variances. Non-euclidean distances between objects and group centroids are handled by reducing the original distances to principal coordinates. This procedure has latterly been used as a means of assessing beta diversity. There are anova, scores, plot and boxplot methods. TukeyHSD.betadisper creates a set of confidence intervals on the differences between the mean distance-to-centroid of the levels of the grouping factor with the specified family-wise probability of coverage. The intervals are based on the Studentized range statistic, Tukey's 'Honest Significant Difference' method.

dist.data<-vegdist(data[,5:7])
data$SexYear<-as.factor(paste(data$Sex, data$Year))

(mod <- betadisper(dist.data, data$Sex))
	# Homogeneity of multivariate dispersions

# Call: betadisper(d = dist.data, group = data$Sex)

# No. of Positive Eigenvalues: 163
# No. of Negative Eigenvalues: 350

# Average distance to median:
     # F      M 
# 0.1155 0.1234 

# Eigenvalues for PCoA axes:
# (Showing 8 of 513 eigenvalues)
   # PCoA1    PCoA2    PCoA3    PCoA4    PCoA5    PCoA6    PCoA7    PCoA8 
# 10.11435  0.62315  0.17151  0.14314  0.09396  0.06414  0.04898  0.04146 
plot(mod)
boxplot(mod)

anova(mod)
# Analysis of Variance Table

# Response: Distances
           # Df Sum Sq   Mean Sq F value Pr(>F)
# Groups      1 0.0057 0.0056652   0.783 0.3766
# Residuals 512 3.7043 0.0072350 

set.seed(1234)
permutest(mod)
# Permutation test for homogeneity of multivariate dispersions
# Permutation: free
# Number of permutations: 999

# Response: Distances
           # Df Sum Sq   Mean Sq     F N.Perm Pr(>F)
# Groups      1 0.0057 0.0056652 0.783    999  0.381
# Residuals 512 3.7043 0.0072350 

(mod2 <- betadisper(dist.data, data$SexYear))
	# Homogeneity of multivariate dispersions

# Call: betadisper(d = dist.data, group = data$SexYear)

# No. of Positive Eigenvalues: 163
# No. of Negative Eigenvalues: 350

# Average distance to median:
 # F 2016  F 2017  M 2016  M 2017 
# 0.12219 0.09047 0.13099 0.08914 

# Eigenvalues for PCoA axes:
# (Showing 8 of 513 eigenvalues)
   # PCoA1    PCoA2    PCoA3    PCoA4    PCoA5    PCoA6    PCoA7    PCoA8 
# 10.11435  0.62315  0.17151  0.14314  0.09396  0.06414  0.04898  0.04146

set.seed(1234)
permutest(mod2)
# Permutation test for homogeneity of multivariate dispersions
# Permutation: free
# Number of permutations: 999

# Response: Distances
           # Df  Sum Sq  Mean Sq      F N.Perm Pr(>F)    
# Groups      3 0.19328 0.064426 11.148    999  0.001 ***
# Residuals 510 2.94740 0.005779                         
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

plot(mod2)
boxplot(mod2)
anova(mod2)
# Analysis of Variance Table

# Response: Distances
           # Df  Sum Sq  Mean Sq F value    Pr(>F)    
# Groups      3 0.19328 0.064426  11.148 4.259e-07 ***
# Residuals 510 2.94740 0.005779                      
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

TukeyHSD(mod2)
# Fit: aov(formula = distances ~ group, data = df)

# $group
                      # diff         lwr          upr     p adj
# F 2017-F 2016 -0.031723722 -0.06911493  0.005667482 0.1282472
# M 2016-F 2016  0.008797012 -0.01882328  0.036417307 0.8445673
# M 2017-F 2016 -0.033057516 -0.05877276 -0.007342277 0.0054365
# M 2016-F 2017  0.040520734  0.00660039  0.074441077 0.0117112
# M 2017-F 2017 -0.001333795 -0.03372179  0.031054205 0.9995716
# M 2017-M 2016 -0.041854528 -0.06219565 -0.021513409 0.0000010

############################################################
############################################################
############################################################
sessionInfo()
# R version 3.6.2 (2019-12-12)
# Platform: x86_64-apple-darwin15.6.0 (64-bit)
# Running under: OS X El Capitan 10.11.6

# Matrix products: default
# BLAS:   /Library/Frameworks/R.framework/Versions/3.6/Resources/lib/libRblas.0.dylib
# LAPACK: /Library/Frameworks/R.framework/Versions/3.6/Resources/lib/libRlapack.dylib

# locale:
# [1] en_US.UTF-8/en_US.UTF-8/en_US.UTF-8/C/en_US.UTF-8/en_US.UTF-8

# attached base packages:
# [1] stats     graphics  grDevices utils     datasets  methods   base     

# other attached packages:
# [1] vegan_2.5-6     lattice_0.20-41 permute_0.9-5  

# loaded via a namespace (and not attached):
 # [1] MASS_7.3-51.5  compiler_3.6.2 Matrix_1.2-18  parallel_3.6.2 tools_3.6.2   
 # [6] mgcv_1.8-31    splines_3.6.2  nlme_3.1-147   grid_3.6.2     cluster_2.1.0  