############### Goedert et al - Frog Color: ###############
# Goedert, D., Clement, D., Calsbeek, R. Evolutionary trade-offs may interact with physiological constraints to maintain color variation. Ecological Monographs.
#################################################
########## Goedert et al - Rscript Pictures - Fitness ###########
## Created by: D. Goedert - 2020-06-04
## Input: tables with color data from pictures, survival from Goedert and Calsbeek 2019, and egg counts
## This script tests for color relationship with on survival or reproductive investment
##### Modified 2020-06-11: adding sex to the model
#################################################
############### Chapter 2- Frog Color: ###############
setwd("drag and drop Codes-Pictures folder in here")
### Note: actually replace everything in between " " for the file path to the Dryad folder.
inputpath<-"./DataSets"
#################################################
data<-read.csv(paste(inputpath, "Color_selection.csv", sep="/"))[,-1]
data$Replica<-as.factor(data$Replica)
str(data)
# 'data.frame':	196 obs. of  17 variables:
 # $ FullID     : Factor w/ 196 levels "2016-CEF1","2016-CEF2",..: 1 2 3 4 5 6 7 8 9 10 ...
 # $ W          : int  0 1 1 0 0 1 1 1 1 0 ...
 # $ Replica    : Factor w/ 4 levels "1","2","3","4": 2 1 2 1 2 1 2 1 1 2 ...
 # $ Year.x     : int  2016 2016 2016 2016 2016 2016 2016 2016 2016 2016 ...
 # $ Mass       : num  19.7 26.1 23.8 24.9 16.1 ...
 # $ PostLayMass: num  13.8 17.2 17.5 16 11.4 ...
 # $ SVL        : num  51.7 58.8 58.5 58.2 51.1 55.8 37.8 47.4 56.1 55.9 ...
 # $ Rs         : num  71.1 70.2 103.2 59.2 110.5 ...
 # $ Gs         : num  70.2 67.1 84.9 60.7 77.8 ...
 # $ Bs         : num  60.1 56.5 66.7 51.1 58.8 ...
 # $ h          : num  0.1536 0.1289 0.0828 0.1924 0.0612 ...
 # $ s          : num  0.155 0.196 0.354 0.157 0.468 ...
 # $ v          : num  0.279 0.275 0.405 0.238 0.433 ...
 # $ Year.y     : int  2016 2016 2016 2016 2016 2016 2016 2016 2016 2016 ...
 # $ Pop        : Factor w/ 10 levels "CE","CM","CW",..: 1 1 1 1 1 1 1 1 3 3 ...
 # $ Sex        : Factor w/ 2 levels "F","M": 1 1 1 1 1 1 2 2 1 1 ...
 # $ pc1_rgb    : num  -10.3 -13.6 25.3 -27.3 25.7 ...

############################################################
############################################################
####################### SURVIVAL #######################
############################################################
### 1) Full Model (quadratic + interaction)
############################################################
summary(lm(W~SVL*pc1_rgb*Sex+I(pc1_rgb^2)+Replica, data))
# Call:
# lm(formula = W ~ SVL * pc1_rgb * Sex + I(pc1_rgb^2) + Replica, 
    # data = data)

# Residuals:
    # Min      1Q  Median      3Q     Max 
# -0.6522 -0.2737 -0.1837  0.4740  0.8790 

# Coefficients:
                   # Estimate Std. Error t value Pr(>|t|)  
# (Intercept)      -1.541e+00  1.475e+00  -1.045   0.2974  
# SVL               3.590e-02  2.660e-02   1.350   0.1787  
# pc1_rgb          -4.971e-03  5.951e-02  -0.084   0.9335  
# SexM              2.122e+00  1.631e+00   1.301   0.1950  
# I(pc1_rgb^2)     -2.403e-05  4.698e-05  -0.512   0.6096  
# Replica2         -5.610e-02  9.424e-02  -0.595   0.5524  
# Replica3         -2.051e-01  1.081e-01  -1.897   0.0593 .
# Replica4         -1.800e-01  1.074e-01  -1.676   0.0954 .
# SVL:pc1_rgb       1.885e-04  1.082e-03   0.174   0.8619  
# SVL:SexM         -4.028e-02  3.058e-02  -1.317   0.1894  
# pc1_rgb:SexM      4.236e-02  6.881e-02   0.616   0.5389  
# SVL:pc1_rgb:SexM -1.011e-03  1.306e-03  -0.774   0.4398  
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Residual standard error: 0.4427 on 184 degrees of freedom
# Multiple R-squared:  0.08853,	Adjusted R-squared:  0.03403 
# F-statistic: 1.625 on 11 and 184 DF,  p-value: 0.09481

############################################################
### 2) Remove interaction
############################################################
summary(lm(W~SVL*Sex+pc1_rgb*Sex+I(pc1_rgb^2)+Replica, data))
# Call:
# lm(formula = W ~ SVL * Sex + pc1_rgb * Sex + I(pc1_rgb^2) + Replica, 
    # data = data)

# Residuals:
    # Min      1Q  Median      3Q     Max 
# -0.6427 -0.2820 -0.1895  0.4601  0.9002 

# Coefficients:
               # Estimate Std. Error t value Pr(>|t|)  
# (Intercept)  -1.604e+00  1.444e+00  -1.111   0.2681  
# SVL           3.698e-02  2.602e-02   1.421   0.1570  
# SexM          2.318e+00  1.599e+00   1.449   0.1489  
# pc1_rgb       5.345e-03  3.061e-03   1.746   0.0824 .
# I(pc1_rgb^2) -2.644e-05  4.683e-05  -0.565   0.5730  
# Replica2     -4.159e-02  9.277e-02  -0.448   0.6544  
# Replica3     -1.909e-01  1.071e-01  -1.782   0.0763 .
# Replica4     -1.738e-01  1.069e-01  -1.625   0.1058  
# SVL:SexM     -4.425e-02  2.996e-02  -1.477   0.1414  
# SexM:pc1_rgb -6.669e-03  3.453e-03  -1.932   0.0549 .
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Residual standard error: 0.4419 on 186 degrees of freedom
# Multiple R-squared:  0.08189,	Adjusted R-squared:  0.03747 
# F-statistic: 1.843 on 9 and 186 DF,  p-value: 0.06307

############################################################
### 3) Remove quadratic
############################################################
summary(lm(W~SVL*Sex+pc1_rgb*Sex+Replica, data))
# Call:
# lm(formula = W ~ SVL * Sex + pc1_rgb * Sex + Replica, data = data)

# Residuals:
    # Min      1Q  Median      3Q     Max 
# -0.6770 -0.2762 -0.1882  0.4188  0.8754 

# Coefficients:
              # Estimate Std. Error t value Pr(>|t|)  
# (Intercept)  -1.667504   1.437086  -1.160   0.2474  
# SVL           0.037889   0.025928   1.461   0.1456  
# SexM          2.428229   1.584411   1.533   0.1271  
# pc1_rgb       0.004888   0.002947   1.659   0.0988 .
# Replica2     -0.042147   0.092596  -0.455   0.6495  
# Replica3     -0.176704   0.103926  -1.700   0.0907 .
# Replica4     -0.160942   0.104284  -1.543   0.1244  
# SVL:SexM     -0.046634   0.029610  -1.575   0.1170  
# SexM:pc1_rgb -0.006490   0.003432  -1.891   0.0602 .
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Residual standard error: 0.4411 on 187 degrees of freedom
# Multiple R-squared:  0.08032,	Adjusted R-squared:  0.04097 
# F-statistic: 2.041 on 8 and 187 DF,  p-value: 0.04375

############################################################
### 3) Remove interaction between SVL and Sex
############################################################
summary(lm(W~SVL+pc1_rgb*Sex+Replica, data))
# Call:
# lm(formula = W ~ SVL + pc1_rgb * Sex + Replica, data = data)

# Residuals:
    # Min      1Q  Median      3Q     Max 
# -0.6691 -0.2862 -0.1868  0.4955  0.8719 

# Coefficients:
              # Estimate Std. Error t value Pr(>|t|)  
# (Intercept)   0.302099   0.710741   0.425   0.6713  
# SVL           0.002250   0.012707   0.177   0.8596  
# pc1_rgb       0.005507   0.002932   1.878   0.0619 .
# SexM         -0.057649   0.138252  -0.417   0.6772  
# Replica2     -0.045280   0.092938  -0.487   0.6267  
# Replica3     -0.158883   0.103714  -1.532   0.1272  
# Replica4     -0.140965   0.103917  -1.357   0.1766  
# pc1_rgb:SexM -0.006978   0.003431  -2.034   0.0434 *
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Residual standard error: 0.4429 on 188 degrees of freedom
# Multiple R-squared:  0.06812,	Adjusted R-squared:  0.03342 
# F-statistic: 1.963 on 7 and 188 DF,  p-value: 0.06212

levels(data$Sex)
inv.data<-data
inv.data$Sex<-factor(inv.data$Sex, levels=c("M", "F"))
summary(lm(W~SVL+pc1_rgb*Sex+Replica, inv.data))
# Call:
# lm(formula = W ~ SVL + pc1_rgb * Sex + Replica, data = inv.data)

# Residuals:
    # Min      1Q  Median      3Q     Max 
# -0.6691 -0.2862 -0.1868  0.4955  0.8719 

# Coefficients:
              # Estimate Std. Error t value Pr(>|t|)  
# (Intercept)   0.244450   0.608007   0.402   0.6881  
# SVL           0.002250   0.012707   0.177   0.8596  
# pc1_rgb      -0.001472   0.001722  -0.855   0.3937  
# SexF          0.057649   0.138252   0.417   0.6772  
# Replica2     -0.045280   0.092938  -0.487   0.6267  
# Replica3     -0.158883   0.103714  -1.532   0.1272  
# Replica4     -0.140965   0.103917  -1.357   0.1766  
# pc1_rgb:SexF  0.006978   0.003431   2.034   0.0434 *
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Residual standard error: 0.4429 on 188 degrees of freedom
# Multiple R-squared:  0.06812,	Adjusted R-squared:  0.03342 
# F-statistic: 1.963 on 7 and 188 DF,  p-value: 0.06212

############################################################
############################################################
############################################################
### Per Sex dataset:
############################################################
males<-data[data$Sex=="M",]
females<-data[data$Sex=="F",]
############################################################
### MALES:
############################################################
###### 1) Full:
summary(lm(W~SVL*pc1_rgb+I(pc1_rgb^2)+Replica, males))
# Call:
# lm(formula = W ~ SVL * pc1_rgb + I(pc1_rgb^2) + Replica, data = males)

# Residuals:
     # Min       1Q   Median       3Q      Max 
# -0.46048 -0.24472 -0.18113 -0.05358  0.86409 

# Coefficients:
               # Estimate Std. Error t value Pr(>|t|)
# (Intercept)   5.111e-01  6.894e-01   0.741    0.460
# SVL          -4.385e-03  1.458e-02  -0.301    0.764
# pc1_rgb       3.337e-02  3.299e-02   1.012    0.313
# I(pc1_rgb^2) -4.140e-06  5.101e-05  -0.081    0.935
# Replica2      5.321e-02  1.209e-01   0.440    0.661
# Replica3     -1.389e-01  1.141e-01  -1.217    0.225
# Replica4     -1.151e-01  1.131e-01  -1.018    0.311
# SVL:pc1_rgb  -7.388e-04  7.003e-04  -1.055    0.293

# Residual standard error: 0.4298 on 145 degrees of freedom
# Multiple R-squared:  0.04518,	Adjusted R-squared:  -0.0009109 
# F-statistic: 0.9802 on 7 and 145 DF,  p-value: 0.448

###### 2) Remove interaction:
summary(lm(W~SVL+pc1_rgb+I(pc1_rgb^2)+Replica, males))
# Call:
# lm(formula = W ~ SVL + pc1_rgb + I(pc1_rgb^2) + Replica, data = males)

# Residuals:
    # Min      1Q  Median      3Q     Max 
# -0.4265 -0.2307 -0.1893 -0.1201  0.8757 

# Coefficients:
               # Estimate Std. Error t value Pr(>|t|)
# (Intercept)   6.240e-01  6.813e-01   0.916    0.361
# SVL          -6.895e-03  1.439e-02  -0.479    0.632
# pc1_rgb      -1.382e-03  1.757e-03  -0.787    0.433
# I(pc1_rgb^2) -6.396e-06  5.099e-05  -0.125    0.900
# Replica2      7.254e-02  1.196e-01   0.607    0.545
# Replica3     -1.230e-01  1.131e-01  -1.088    0.279
# Replica4     -1.064e-01  1.128e-01  -0.943    0.347

# Residual standard error: 0.43 on 146 degrees of freedom
# Multiple R-squared:  0.03785,	Adjusted R-squared:  -0.001686 
# F-statistic: 0.9574 on 6 and 146 DF,  p-value: 0.4564

###### 3) Remove quadratic:
summary(lm(W~SVL+pc1_rgb+Replica, males))
# Call:
# lm(formula = W ~ SVL + pc1_rgb + Replica, data = males)

# Residuals:
    # Min      1Q  Median      3Q     Max 
# -0.4371 -0.2306 -0.1883 -0.1315  0.8695 

# Coefficients:
             # Estimate Std. Error t value Pr(>|t|)
# (Intercept)  0.634007   0.674369   0.940    0.349
# SVL         -0.007238   0.014079  -0.514    0.608
# pc1_rgb     -0.001448   0.001671  -0.866    0.388
# Replica2     0.073549   0.118880   0.619    0.537
# Replica3    -0.119023   0.108138  -1.101    0.273
# Replica4    -0.102736   0.108589  -0.946    0.346

# Residual standard error: 0.4285 on 147 degrees of freedom
# Multiple R-squared:  0.03775,	Adjusted R-squared:  0.005021 
# F-statistic: 1.153 on 5 and 147 DF,  p-value: 0.335
############################################################
### FEMALES:
############################################################
###### 1) Full:
summary(lm(W~SVL*pc1_rgb+I(pc1_rgb^2)+Replica, females))
# Call:
# lm(formula = W ~ SVL * pc1_rgb + I(pc1_rgb^2) + Replica, data = females)

# Residuals:
    # Min      1Q  Median      3Q     Max 
# -0.7339 -0.3970 -0.1629  0.4623  0.8501 

# Coefficients:
               # Estimate Std. Error t value Pr(>|t|)
# (Intercept)  -1.164e+00  1.660e+00  -0.701    0.487
# SVL           3.059e-02  2.974e-02   1.029    0.310
# pc1_rgb      -1.435e-02  6.633e-02  -0.216    0.830
# I(pc1_rgb^2) -7.532e-05  1.188e-04  -0.634    0.530
# Replica2     -1.867e-01  1.627e-01  -1.148    0.259
# SVL:pc1_rgb   3.904e-04  1.208e-03   0.323    0.748

# Residual standard error: 0.4896 on 37 degrees of freedom
# Multiple R-squared:  0.1526,	Adjusted R-squared:  0.03807 
# F-statistic: 1.332 on 5 and 37 DF,  p-value: 0.2721

###### 2) Remove interaction:
summary(lm(W~SVL+pc1_rgb+I(pc1_rgb^2)+Replica, females))
# Call:
# lm(formula = W ~ SVL + pc1_rgb + I(pc1_rgb^2) + Replica, data = females)

# Residuals:
    # Min      1Q  Median      3Q     Max 
# -0.7163 -0.3939 -0.1271  0.4505  0.8305 

# Coefficients:
               # Estimate Std. Error t value Pr(>|t|)  
# (Intercept)  -1.276e+00  1.604e+00  -0.795   0.4315  
# SVL           3.260e-02  2.874e-02   1.134   0.2637  
# pc1_rgb       7.057e-03  3.798e-03   1.858   0.0709 .
# I(pc1_rgb^2) -7.477e-05  1.174e-04  -0.637   0.5281  
# Replica2     -1.776e-01  1.583e-01  -1.122   0.2690  
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Residual standard error: 0.4838 on 38 degrees of freedom
# Multiple R-squared:  0.1502,	Adjusted R-squared:  0.06074 
# F-statistic: 1.679 on 4 and 38 DF,  p-value: 0.175

###### 3) Remove quadratic:
summary(lm(W~SVL+pc1_rgb+Replica, females))
# Call:
# lm(formula = W ~ SVL + pc1_rgb + Replica, data = females)

# Residuals:
    # Min      1Q  Median      3Q     Max 
# -0.6978 -0.3985 -0.1144  0.4540  0.8273 

# Coefficients:
             # Estimate Std. Error t value Pr(>|t|)  
# (Intercept) -1.427401   1.574373  -0.907   0.3702  
# SVL          0.034805   0.028312   1.229   0.2263  
# pc1_rgb      0.005880   0.003293   1.786   0.0819 .
# Replica2    -0.197090   0.154124  -1.279   0.2085  
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Residual standard error: 0.4801 on 39 degrees of freedom
# Multiple R-squared:  0.1411,	Adjusted R-squared:  0.07505 
# F-statistic: 2.136 on 3 and 39 DF,  p-value: 0.1113

############################################################
############################################################
############################################################
##### Does anything change if considering Replicate as random term?
## Note: 2 of the Replicates have no females
library(lmerTest)
summary(lmer(W~SVL+pc1_rgb*Sex+(1|Replica), data))
# boundary (singular) fit: see ?isSingular
# Linear mixed model fit by REML. t-tests use Satterthwaite's method [
# lmerModLmerTest]
# Formula: W ~ SVL + pc1_rgb * Sex + (1 | Replica)
   # Data: data

# REML criterion at convergence: 267.9

# Scaled residuals: 
    # Min      1Q  Median      3Q     Max 
# -1.5389 -0.6079 -0.4946  1.1107  1.9267 

# Random effects:
 # Groups   Name        Variance Std.Dev.
 # Replica  (Intercept) 0.0000   0.0000  
 # Residual             0.1958   0.4425  
# Number of obs: 196, groups:  Replica, 4

# Fixed effects:
               # Estimate Std. Error         df t value Pr(>|t|)  
# (Intercept)   -0.064859   0.670837 191.000000  -0.097   0.9231  
# SVL            0.008525   0.012085 191.000000   0.705   0.4814  
# pc1_rgb        0.005126   0.002870 191.000000   1.786   0.0756 .
# SexM          -0.084189   0.136538 191.000000  -0.617   0.5382  
# pc1_rgb:SexM  -0.007144   0.003338 191.000000  -2.140   0.0336 *
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Correlation of Fixed Effects:
            # (Intr) SVL    pc1_rg SexM  
# SVL         -0.995                     
# pc1_rgb      0.060 -0.071              
# SexM        -0.873  0.827 -0.009       
# pc1_rgb:SxM -0.133  0.143 -0.866  0.074
# convergence code: 0
# boundary (singular) fit: see ?isSingular

summary(lmer(W~SVL+pc1_rgb*Sex+(1|Replica), inv.data))
# boundary (singular) fit: see ?isSingular
# Linear mixed model fit by REML. t-tests use Satterthwaite's method [
# lmerModLmerTest]
# Formula: W ~ SVL + pc1_rgb * Sex + (1 | Replica)
   # Data: inv.data

# REML criterion at convergence: 267.9

# Scaled residuals: 
    # Min      1Q  Median      3Q     Max 
# -1.5389 -0.6079 -0.4946  1.1107  1.9267 

# Random effects:
 # Groups   Name        Variance Std.Dev.
 # Replica  (Intercept) 0.0000   0.0000  
 # Residual             0.1958   0.4425  
# Number of obs: 196, groups:  Replica, 4

# Fixed effects:
               # Estimate Std. Error         df t value Pr(>|t|)  
# (Intercept)   -0.149048   0.555586 191.000000  -0.268   0.7888  
# SVL            0.008525   0.012085 191.000000   0.705   0.4814  
# pc1_rgb       -0.002018   0.001672 191.000000  -1.207   0.2290  
# SexF           0.084189   0.136538 191.000000   0.617   0.5382  
# pc1_rgb:SexF   0.007144   0.003338 191.000000   2.140   0.0336 *
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Correlation of Fixed Effects:
            # (Intr) SVL    pc1_rg SexF  
# SVL         -0.998                     
# pc1_rgb     -0.164  0.164              
# SexF         0.809 -0.827 -0.134       
# pc1_rgb:SxF  0.143 -0.143 -0.511  0.074
# convergence code: 0
# boundary (singular) fit: see ?isSingular
############################################################
############################################################
sessionInfo()
# R version 3.6.2 (2019-12-12)
# Platform: x86_64-apple-darwin15.6.0 (64-bit)
# Running under: OS X El Capitan 10.11.6

# Matrix products: default
# BLAS:   /Library/Frameworks/R.framework/Versions/3.6/Resources/lib/libRblas.0.dylib
# LAPACK: /Library/Frameworks/R.framework/Versions/3.6/Resources/lib/libRlapack.dylib

# locale:
# [1] en_US.UTF-8/en_US.UTF-8/en_US.UTF-8/C/en_US.UTF-8/en_US.UTF-8

# attached base packages:
# [1] stats     graphics  grDevices utils     datasets  methods  
# [7] base     

# other attached packages:
# [1] lmerTest_3.1-2 lme4_1.1-23    Matrix_1.2-18 

# loaded via a namespace (and not attached):
 # [1] Rcpp_1.0.4.6        magrittr_1.5        splines_3.6.2      
 # [4] MASS_7.3-51.5       tidyselect_1.0.0    munsell_0.5.0      
 # [7] statmod_1.4.34      colorspace_1.4-1    lattice_0.20-41    
# [10] R6_2.4.1            rlang_0.4.5         minqa_1.2.4        
# [13] dplyr_0.8.5         grid_3.6.2          gtable_0.3.0       
# [16] nlme_3.1-147        ellipsis_0.3.0      assertthat_0.2.1   
# [19] tibble_3.0.1        lifecycle_0.2.0     numDeriv_2016.8-1.1
# [22] crayon_1.3.4        purrr_0.3.4         nloptr_1.2.2.1     
# [25] ggplot2_3.3.0       vctrs_0.2.4         glue_1.4.0         
# [28] compiler_3.6.2      pillar_1.4.3        scales_1.1.0       
# [31] boot_1.3-24         pkgconfig_2.0.3