############### Goedert et al - Frog Color: ###############
# Goedert, D., Clement, D., Calsbeek, R. Evolutionary trade-offs may interact with physiological constraints to maintain color variation. Ecological Monographs.
#################################################
## - Rscript Plots - JND ~ PC - Figures 6 and SM.5
## Created by: D. Goedert, 2020-05-27: double-checked 2020-07-14
#################################################
############### Chapter 2- Frog Color: ###############
setwd("../../Codes-Specs")
### Note: actually replace everything in between " " for the file path to the Dryad folder.
inputpath<-"./8Analises_PredVision/ColDist_8.4.ContrastPC1/results_ContrastPC1_PE"
dir(inputpath)
library(ggplot2)
#################################################
data<-read.csv(paste(inputpath, "results_PE.csv", sep="/"))
str(data)
# 'data.frame':	960 obs. of  8 variables:
 # $ Variable     : Factor w/ 20 levels "traitBirchLeavesDark_bkg",..: 1 3 5 7 9 11 13 15 17 19 ...
 # $ PosteriorMean: num  3.32 5.13 1.78 1.57 1.11 ...
 # $ LowCI        : num  2.761 4.578 1.306 1.123 0.899 ...
 # $ HighCI       : num  3.91 5.72 2.31 2.01 1.32 ...
 # $ SampleSize   : int  4794 5000 5000 5000 5204 4375 5000 5000 4798 5000 ...
 # $ pMCMC        : Factor w/ 27 levels "<2e-04","0.0004",..: 1 1 1 1 1 1 1 1 1 1 ...
 # $ model        : Factor w/ 24 levels "1_achr_kestrel_dc_ideal",..: 1 1 1 1 1 1 1 1 1 1 ...
 # $ run          : Factor w/ 2 levels "run2","run3": 1 1 1 1 1 1 1 1 1 1 ...

## 24 models x 10 bkg x 2 coeff (slope+intercept) x 2 runs = 960
data_r2<-data[data$run=="run2",]
str(data_r2) # ok!
############################################################
slope_r2<-data_r2[grep(":pc1", data_r2$Variable),]
dim(slope_r2)
# [1] 240   8
############################################################
####### Reorder, spell out factors, and renumber models to match Table in SM
############################################################
############# BKG: 
slope_r2$bkg<-as.factor(gsub("_.*|trait", "", slope_r2$Variable))

slope_r2$bkg2<-factor(gsub("BirchLeavesWet", "Leaf Litter: Birch (Wet)", gsub("BirchLeavesDark", "Leaf Litter: Birch (Dark)", gsub("BirchLeavesLight", "Leaf Litter: Birch (Light)", gsub("Dirt", "Exposed soil", gsub("MapleLeaves", "Leaf Litter: Maple (Dry)", gsub("MapleLeavesWet", "Leaf Litter: Maple (Wet)", gsub("OakLeaveDark", "Leaf Litter: Oak (Dark)", gsub("OakLeaveLight", "Leaf Litter: Oak (Light)", gsub("PineNeedles", "Leaf Litter: Pine Needles", slope_r2$bkg))))))))), levels=c("Exposed soil", "Grass", "Leaf Litter: Birch (Dark)", "Leaf Litter: Birch (Light)","Leaf Litter: Birch (Wet)", "Leaf Litter: Maple (Dry)", "Leaf Litter: Maple (Wet)", "Leaf Litter: Oak (Dark)", "Leaf Litter: Oak (Light)","Leaf Litter: Pine Needles"))

slope_r2$bkg<-factor(gsub("BirchLeavesWet", "Birch (Wet)", gsub("BirchLeavesDark", "Birch (Dark)", gsub("BirchLeavesLight", "Birch (Light)", gsub("Dirt", "Exposed soil", gsub("MapleLeaves", "Maple (Dry)", gsub("MapleLeavesWet", "Maple (Wet)", gsub("OakLeaveDark", "Oak (Dark)", gsub("OakLeaveLight", "Oak (Light)", gsub("PineNeedles", "Pine Needles", slope_r2$bkg))))))))), levels=c("Exposed soil", "Grass", "Birch (Dark)", "Birch (Light)","Birch (Wet)", "Maple (Dry)", "Maple (Wet)", "Oak (Dark)", "Oak (Light)","Pine Needles"))

slope_r2$bkg_rev<-factor(slope_r2$bkg, levels=rev(levels(slope_r2$bkg)))
slope_r2$bkg2_rev<-factor(slope_r2$bkg2, levels=rev(levels(slope_r2$bkg2)))
############################################################
############# MODEL CATEGORY: 
slope_r2$pred_channel<-factor(ifelse(grepl("achr_kestrel", slope_r2$model), "Kestrel: Achromatic", ifelse(grepl("chrom_kestrel", slope_r2$model), "Kestrel: Chromatic", ifelse(grepl("achr_snake", slope_r2$model), "Snake: Achromatic",  "Snake: Chromatic"))), levels=c("Snake: Chromatic", "Kestrel: Chromatic", "Snake: Achromatic", "Kestrel: Achromatic"))
slope_r2[,c("model","pred_channel")]
############################################################
############# MODEL NUMBER: 
levels(slope_r2$model)

slope_r2$whichmodel<-factor(gsub("24_chrom_snake_w01_vK", "1", 
gsub("23_chrom_snake_w01_novkFS", "2",
gsub("22_chrom_snake_w01_novkBS", "3",
gsub("21_chrom_snake_w005_vK", "4",
gsub("20_chrom_snake_w005_novkFS", "5",
gsub("19_chrom_snake_w005_novkBS", "6",
gsub("18_chrom_kestrel_od_vK","7",
gsub("17_chrom_kestrel_od_novkFS","8",
gsub("16_chrom_kestrel_od_novkBS","9",
gsub("15_chrom_kestrel_nodrop_vK" , "10",
gsub("14_chrom_kestrel_nodrop_novkFS", "11",
gsub("13_chrom_kestrel_nodrop_novkBS", "12",
gsub("10_achr_snake_w01_ideal", "13",
gsub("12_achr_snake_w01_novkFS", "14",
gsub("11_achr_snake_w01_novkBS", "15",
gsub("7_achr_snake_w005_ideal","16",
gsub("9_achr_snake_w005_novkFS","17",
gsub("8_achr_snake_w005_novkBS" ,"18",
gsub("4_achr_kestrel_lws_ideal","19",
gsub("6_achr_kestrel_lws_novkFS", "20",
gsub("5_achr_kestrel_lws_novkBS","21",
gsub("1_achr_kestrel_dc_ideal","22",
gsub("3_achr_kestrel_dc_novkFS","23",
gsub("2_achr_kestrel_dc_novkBS","24",slope_r2$model)))))))))))))))))))))))), levels=c(1:24))

slope_r2$whichmodel_rev<-factor(slope_r2$whichmodel, levels=c(24:1))
############################################################
max(slope_r2$HighCI)
# [1] 0.102235
min(slope_r2$LowCI)
# [1] -0.131496

subset_r2<-slope_r2[slope_r2$whichmodel %in% c("4","7","16","22"),]
subset_r2$pred<-factor(gsub(": .*", "", subset_r2$pred_channel))
subset_r2$channel<-factor(gsub(".*: ", "", subset_r2$pred_channel), levels=c("Chromatic", "Achromatic"))
pd <- position_dodge(0.5)
############################################################
############################################################
############################################################
################ Main manuscript - new figure
whatcolor<-rep(c(rgb(54/255,100/255,139/255), rgb(163/255, 206/255,250/255, alpha=0.9), rgb(134/255,238/255,134/255, alpha=0.9),rgb(105/255,139/255,105/255)), each=10)

plot_newFig<-ggplot(subset_r2, aes(x=PosteriorMean, y=bkg_rev, group=channel, shape=pred_channel, color=pred_channel))+
	geom_linerange(aes(xmin=LowCI, xmax=HighCI), position=pd, size=1)+
	geom_point(position=pd, size=4)+
	geom_vline(xintercept=0, linetype="dotted", color="grey", size=1)+
	xlab("Slope of the regreesion between JND and PC1") + ylab("Background")+
	facet_wrap(pred~.)+
	scale_shape_manual(name = "Channel", values=c(16,16,24,24))+
	scale_color_manual(name = "Channel", 
	values=c(rgb(134/255,238/255,134/255, alpha=0.9), rgb(163/255, 206/255,250/255, alpha=0.9), rgb(105/255,139/255,105/255), rgb(54/255,100/255,139/255)))+ ### works!!
	guides(color=guide_legend(nrow=2), shape=guide_legend(nrow=2))+
	theme_bw()+theme(panel.grid=element_blank(), legend.position="top",axis.text.x=element_text(size=13), axis.text.y=element_text(size=13), text=element_text(size=18))

# pdf("../Revisions/NewFigures_Output/NewFig_JNDPC1.pdf", width=12, height=8)
plot_newFig
# dev.off()

############################################################
############################################################
############################################################
############################################################
################ SM - new figure
plot_newSM<-ggplot(slope_r2, aes(x=PosteriorMean, y=whichmodel_rev, color=pred_channel))+geom_point(size=3)+geom_segment(aes(x=LowCI, xend=HighCI, y=whichmodel_rev, yend=whichmodel_rev), size=1.5)+geom_vline(xintercept=0, linetype="dotted", size=0.5)+
scale_color_manual(name = "Predator: Channel", values=c(rgb(80/255,205/255,205/255, alpha=0.8), rgb(255/255, 185/255,15/255, alpha=0.8), rgb(104/255,131/255,139/255, alpha=0.6), rgb(179/255,141/255,10/255, alpha=0.6)))+
xlab("Slope of the regreesion between JND and PC1") + ylab("Type of Visual Model")+
scale_x_continuous(limits=c(-0.15, 0.15))+
facet_wrap(~bkg2, ncol=5)+
theme_bw()+
theme(panel.grid.minor=element_blank(), legend.position="top",axis.text.x=element_text(size=13), axis.text.y=element_text(size=13), text=element_text(size=18))

# pdf("../Revisions/NewFigures_Output/NewSM_JNDPC1.pdf", width=12, height=10)
plot_newSM
# dev.off()
############################################################
############################################################
sessionInfo()
# R version 3.6.2 (2019-12-12)
# Platform: x86_64-apple-darwin15.6.0 (64-bit)
# Running under: OS X El Capitan 10.11.6

# Matrix products: default
# BLAS:   /Library/Frameworks/R.framework/Versions/3.6/Resources/lib/libRblas.0.dylib
# LAPACK: /Library/Frameworks/R.framework/Versions/3.6/Resources/lib/libRlapack.dylib

# locale:
# [1] en_US.UTF-8/en_US.UTF-8/en_US.UTF-8/C/en_US.UTF-8/en_US.UTF-8

# attached base packages:
# [1] stats     graphics  grDevices utils     datasets  methods  
# [7] base     

# other attached packages:
# [1] ggplot2_3.3.0

# loaded via a namespace (and not attached):
 # [1] Rcpp_1.0.4.6     digest_0.6.25    withr_2.2.0      assertthat_0.2.1
 # [5] dplyr_0.8.5      crayon_1.3.4     grid_3.6.2       R6_2.4.1        
 # [9] lifecycle_0.2.0  gtable_0.3.0     magrittr_1.5     scales_1.1.0    
# [13] pillar_1.4.3     rlang_0.4.5      farver_2.0.3     vctrs_0.2.4     
# [17] ellipsis_0.3.0   labeling_0.3     glue_1.4.0       purrr_0.3.4     
# [21] munsell_0.5.0    compiler_3.6.2   pkgconfig_2.0.3  colorspace_1.4-1
# [25] tidyselect_1.0.0 tibble_3.0.1    