############### Goedert et al - Frog Color: ###############
# Goedert, D., Clement, D., Calsbeek, R. Evolutionary trade-offs may interact with physiological constraints to maintain color variation. Ecological Monographs.
#################################################
#########    Goedert et al - Rscript Trade-off plost     ########
## Created by: D. Goedert, modified 2020-06-11
# double-checked 2020-07-14
# Fig. 5
###########################################################################
setwd("../../Codes-Specs")
### Note: actually replace everything in between " " for the file path to the Dryad folder.
inputpath<-"./5Distances_Results"
outputpath<-"../Revisions/NewFigures_Output"
#################################################
################## MAIN MODEL: ##################
## consider ideal ilumination, bright condition;	 		         ##
##  various background 												             ##
## w=0.05;  vk                                                                           ##
#################################################
#### Functions, definitions and tools:
library(tidyverse)

removals<-c("2017-FarmM1", "2017-RayM40", "2017-GrM4", "2017-RayM39", "2017-RayM23", "2017-RayM42", "2017-FarmF2", "2017-CWM20" , "2017-FarmM14", "2017-RayM29", "2017-RayM38", "2017-RayM26", "2017-GrM1", "2017-RayM25", "2017-RayM28", "2017-FarmM5")
#################################################
################ LOAD SNAKE  #####################
#################################################
### Data sets
chrom.snake<-read.csv(paste(inputpath, "chrom_snake_w005_vK.csv", sep="/"))[,-1]
str(chrom.snake)
# 'data.frame':	301 obs. of  11 variables:
 # $ patch1              : Factor w/ 301 levels "CEF1_frog","CEF2_frog",..: 61 62 75 275 276 277 278 279 280 281 ...
 # $ BirchLeavesDark_bkg : num  6.49 7.96 8.7 11.74 6.35 ...
 # $ BirchLeavesLight_bkg: num  6.68 8.11 8.84 11.94 6.53 ...
 # $ BirchLeavesWet_bkg  : num  1.73 2.78 3.52 6.79 1.43 ...
 # $ Dirt_bkg            : num  2.619 0.914 0.57 4.539 2.462 ...
 # $ Grass_bkg           : num  8.09 9.58 10.32 13.32 7.96 ...
 # $ MapleLeaves_bkg     : num  0.728 2.223 3.084 5.939 0.505 ...
 # $ MapleLeavesWet_bkg  : num  0.544 1.49 2.369 5.268 0.306 ...
 # $ OakLeaveDark_bkg    : num  7.82 9.09 9.75 13.07 7.63 ...
 # $ OakLeaveLight_bkg   : num  10.3 11.6 12.2 15.5 10.1 ...
 # $ PineNeedles_bkg     : num  2.64 1.43 1.51 2.8 2.74 ...
achrom.snake<-read.csv(paste(inputpath, "achr_snake_w005_ideal.csv", sep="/"))[,-1]
str(achrom.snake)
# 'data.frame':	301 obs. of  11 variables:
 # $ patch1              : Factor w/ 301 levels "CEF1_frog","CEF2_frog",..: 61 62 75 275 276 277 278 279 280 281 ...
 # $ BirchLeavesDark_bkg : num  12.6 16.6 15.6 41.1 20 ...
 # $ BirchLeavesLight_bkg: num  19.4 23.3 22.4 47.8 26.7 ...
 # $ BirchLeavesWet_bkg  : num  4.104 0.175 1.126 24.306 3.208 ...
 # $ Dirt_bkg            : num  2.432 1.497 0.546 25.978 4.88 ...
 # $ Grass_bkg           : num  3.37 7.3 6.35 31.78 10.68 ...
 # $ MapleLeaves_bkg     : num  0.493 4.422 3.471 28.903 7.805 ...
 # $ MapleLeavesWet_bkg  : num  10.4 14.4 13.4 38.9 17.8 ...
 # $ OakLeaveDark_bkg    : num  13.7 17.6 16.6 42.1 21 ...
 # $ OakLeaveLight_bkg   : num  27.1 31 30 55.5 34.4 ...
 # $ PineNeedles_bkg     : num  11.9 15.8 14.9 40.3 19.2 ...
 
### Clean up:
chrom.snake$FullID=as.factor(paste("2017", gsub("_frog", "", chrom.snake$patch1), sep="-"))
chrom.snake<-chrom.snake[!chrom.snake$FullID %in% removals,-1]
str(chrom.snake)
achrom.snake$FullID=as.factor(paste("2017", gsub("_frog", "", achrom.snake$patch1), sep="-"))
achrom.snake<-achrom.snake[!achrom.snake$FullID %in% removals,-1]
str(achrom.snake)

#################################################
################ LOAD KESTREL #####################
#################################################
### Data sets
chrom.kestrel<-read.csv(paste(inputpath, "chrom_kestrel_od_vK.csv", sep="/"))[,-1]
str(chrom.kestrel)
# 'data.frame':	301 obs. of  11 variables:
 # $ patch1              : Factor w/ 301 levels "CEF1_frog","CEF2_frog",..: 61 62 75 275 276 277 278 279 280 281 ...
 # $ BirchLeavesDark_bkg : num  1.14 3.03 3.79 1.17 1.57 ...
 # $ BirchLeavesLight_bkg: num  1.21 2.67 3.36 1.32 1.23 ...
 # $ BirchLeavesWet_bkg  : num  2.001 1.055 1.545 2.243 0.967 ...
 # $ Dirt_bkg            : num  4.049 1.744 0.764 4.303 3.105 ...
 # $ Grass_bkg           : num  5.82 5.51 5.41 5.71 4.87 ...
 # $ MapleLeaves_bkg     : num  0.915 1.476 2.47 1.147 0.73 ...
 # $ MapleLeavesWet_bkg  : num  1.357 1.336 2.119 1.563 0.312 ...
 # $ OakLeaveDark_bkg    : num  2.18 2.14 2.42 2.42 1.44 ...
 # $ OakLeaveLight_bkg   : num  2.77 2.37 2.39 3 1.92 ...
 # $ PineNeedles_bkg     : num  0.761 1.653 2.557 1.087 0.632 ...
achrom.kestrel<-read.csv(paste(inputpath, "achr_kestrel_dc_ideal.csv", sep="/"))[,-1]
str(achrom.kestrel)
# 'data.frame':	301 obs. of  11 variables:
 # $ patch1              : Factor w/ 301 levels "CEF1_frog","CEF2_frog",..: 61 62 75 275 276 277 278 279 280 281 ...
 # $ BirchLeavesDark_bkg : num  3.53 4.8 4.62 11.44 5.7 ...
 # $ BirchLeavesLight_bkg: num  5.34 6.61 6.43 13.25 7.51 ...
 # $ BirchLeavesWet_bkg  : num  1.3061 0.0319 0.2139 6.6017 0.8652 ...
 # $ Dirt_bkg            : num  0.978 0.296 0.114 6.93 1.193 ...
 # $ Grass_bkg           : num  0.373 1.647 1.465 8.28 2.544 ...
 # $ MapleLeaves_bkg     : num  0.0994 1.3737 1.1916 8.0073 2.2708 ...
 # $ MapleLeavesWet_bkg  : num  2.79 4.07 3.88 10.7 4.96 ...
 # $ OakLeaveDark_bkg    : num  3.64 4.91 4.73 11.55 5.81 ...
 # $ OakLeaveLight_bkg   : num  7.29 8.56 8.38 15.2 9.46 ...
 # $ PineNeedles_bkg     : num  3.25 4.53 4.34 11.16 5.42 ...

### Clean up:
chrom.kestrel$FullID=as.factor(paste("2017", gsub("_frog", "", chrom.kestrel$patch1), sep="-"))
chrom.kestrel<-chrom.kestrel[!chrom.kestrel$FullID %in% removals,-1]
str(chrom.kestrel)
achrom.kestrel$FullID=as.factor(paste("2017", gsub("_frog", "", achrom.kestrel$patch1), sep="-"))
achrom.kestrel<-achrom.kestrel[!achrom.kestrel$FullID %in% removals,-1]
str(achrom.kestrel)

#################################################
#################################################
#################################################	
kestrel<-rbind(chrom.kestrel, achrom.kestrel)
kestrel$channel<-as.factor(rep(c("Chromatic", "Achromatic"), each=dim(chrom.kestrel)[1]))
str(kestrel)
snake<-rbind(chrom.snake, achrom.snake)
snake$channel<-as.factor(rep(c("Chromatic", "Achromatic"), each=dim(chrom.snake)[1]))
str(snake)

(kestrel.means<-data.frame(t(apply(kestrel[,1:10], 2, function(x)tapply(x, kestrel$channel, mean)))))
(snake.means<-data.frame(t(apply(snake[,1:10], 2, function(x)tapply(x, snake$channel, mean)))))
colnames(kestrel.means)<-paste("Kestrel",colnames(kestrel.means), sep="_")
kestrel.means$bkg<-rownames(kestrel.means)
colnames(snake.means)<-paste("Snake",colnames(snake.means), sep="_")
snake.means$bkg<-rownames(snake.means)
the.means<-merge(snake.means, kestrel.means, by="bkg")
new.means<-the.means %>%
	gather(value="mean.JND", key="pred.channel", -bkg)
new.means$Predator<-as.factor(gsub("_.*", "", new.means$pred.channel))
new.means$Channel<-as.factor(gsub(".*_", "", new.means$pred.channel))
new.means$Channel<-factor(new.means$Channel, levels=c("Chromatic", "Achromatic"))

# ggplot(new.means, aes(y=mean.JND, group=Predator, x=Channel))+geom_point(aes(color=Predator))+geom_line(aes(color=Predator))+geom_hline(yintercept=1)+facet_wrap(~bkg, ncol=5)+scale_colour_manual(values=c("orange", "blue"))
#################################################
#################################################
complete<-rbind(kestrel, snake)
complete$Predator<-as.factor(rep(c("Kestrel", "Snake"), each=dim(kestrel)[1]))
colnames(complete)
str(complete)
# 'data.frame':	1140 obs. of  13 variables:
 # $ BirchLeavesDark_bkg : num  1.14 3.03 3.79 1.57 2.18 ...
 # $ BirchLeavesLight_bkg: num  1.21 2.67 3.36 1.23 1.72 ...
 # $ BirchLeavesWet_bkg  : num  2.001 1.055 1.545 0.967 0.213 ...
 # $ Dirt_bkg            : num  4.049 1.744 0.764 3.105 2.385 ...
 # $ Grass_bkg           : num  5.82 5.51 5.41 4.87 4.63 ...
 # $ MapleLeaves_bkg     : num  0.915 1.476 2.47 0.73 1.418 ...
 # $ MapleLeavesWet_bkg  : num  1.357 1.336 2.119 0.312 0.699 ...
 # $ OakLeaveDark_bkg    : num  2.178 2.144 2.423 1.439 0.945 ...
 # $ OakLeaveLight_bkg   : num  2.77 2.37 2.39 1.92 1.22 ...
 # $ PineNeedles_bkg     : num  0.761 1.653 2.557 0.632 1.286 ...
 # $ FullID              : Factor w/ 301 levels "2017-CEF1","2017-CEF2",..: 61 62 75 276 279 283 284 285 286 287 ...
 # $ channel             : Factor w/ 2 levels "Achromatic","Chromatic": 2 2 2 2 2 2 2 2 2 2 ...
 # $ Predator            : Factor w/ 2 levels "Kestrel","Snake": 1 1 1 1 1 1 1 1 1 1 ...

#################################################
#################################################
new.chrom.kestrel<- chrom.kestrel %>%
	gather(key="bkg", value="JND", -FullID)
str(new.chrom.kestrel)
new.achrom.kestrel<- achrom.kestrel %>%
	gather(key="bkg", value="JND", -FullID)
str(new.achrom.kestrel)
new.chrom.snake<- chrom.snake %>%
	gather(key="bkg", value="JND", -FullID)
str(new.chrom.snake)
new.achrom.snake<- achrom.snake %>%
	gather(key="bkg", value="JND", -FullID)
str(new.achrom.snake)

kestrel<-rbind(new.chrom.kestrel, new.achrom.kestrel)
kestrel$Channel<-as.factor(rep(c("Chromatic", "Achromatic"), each=dim(new.chrom.kestrel)[1]))
str(kestrel)
snake<-rbind(new.chrom.snake, new.achrom.snake)
snake$Channel<-as.factor(rep(c("Chromatic", "Achromatic"), each=dim(new.chrom.snake)[1]))
str(snake)

complete<-rbind(kestrel, snake)
complete$Predator<-as.factor(rep(c("Kestrel", "Snake"), each=dim(snake)[1]))
complete$Channel<-factor(complete$Channel, levels=c("Chromatic", "Achromatic"))
str(complete)
complete$pred.channel<-as.factor(paste(complete$Predator, complete$Channel, sep="_"))
complete$pred.id<-as.factor(paste(complete$Predator, complete$FullID, sep="_"))
complete$bkg.org2<-as.factor(gsub("BirchLeavesWet_bkg", "Leaf litter: Birch (Wet)", gsub("BirchLeavesDark_bkg", "Leaf litter: Birch (Dark)", gsub("BirchLeavesLight_bkg", "Leaf litter: Birch (Light)", gsub("Dirt_bkg", "Exposed soil", gsub("Grass_bkg", "Grass", gsub("MapleLeaves_bkg", "Leaf litter: Maple (Dry)", gsub("MapleLeavesWet_bkg", "Leaf litter: Maple (Wet)", gsub("OakLeaveDark_bkg", "Leaf litter: Oak (Dark)", gsub("OakLeaveLight_bkg", "Leaf litter: Oak (Light)", gsub("PineNeedles_bkg", "Leaf litter: Pine Needles", complete$bkg)))))))))))
new.means$bkg.org2<-as.factor(gsub("BirchLeavesWet_bkg", "Leaf litter: Birch (Wet)", gsub("BirchLeavesDark_bkg", "Leaf litter: Birch (Dark)", gsub("BirchLeavesLight_bkg", "Leaf litter: Birch (Light)", gsub("Dirt_bkg", "Exposed soil", gsub("Grass_bkg", "Grass", gsub("MapleLeaves_bkg", "Leaf litter: Maple (Dry)", gsub("MapleLeavesWet_bkg", "Leaf litter: Maple (Wet)", gsub("OakLeaveDark_bkg", "Leaf litter: Oak (Dark)", gsub("OakLeaveLight_bkg", "Leaf litter: Oak (Light)", gsub("PineNeedles_bkg", "Leaf litter: Pine Needles", new.means$bkg)))))))))))

#################################################
plot1b<-ggplot(complete, aes(y=JND, group=pred.id, x=Channel))+geom_point(aes(color=Predator), alpha=0.2, size=1.5)+geom_line(aes(color=Predator), alpha=0.2)+facet_wrap(~bkg.org2, ncol=5)+
	geom_point(data=new.means, aes(y=mean.JND, group=Predator, x=Channel), color=rep(c("darkseagreen4", "darkseagreen4", "steelblue4", "steelblue4"), 10), size=3)+
	geom_line(data=new.means, aes(y=mean.JND, group=Predator, x=Channel), color=rep(c("steelblue4", "steelblue4", "darkseagreen4", "darkseagreen4"), 10), size=2)+
	geom_hline(yintercept=1, linetype="dashed", lwd=1.5, alpha=0.25)+
	ylab("Contrast (JND)")+
	scale_color_manual(values=c("skyblue3", "darkseagreen"))+
	theme_bw()+theme(legend.position="top", panel.grid=element_blank(), axis.text.x=element_text(size=20), axis.text.y=element_text(size=25), text=element_text(size=30), strip.text = element_text(size = 20), legend.key.width = unit(1,"cm"))+guides(colour = guide_legend(override.aes = list(size=8, alpha=0.8)))

# pdf(paste(outputpath, "Fig4_JND_TradeOff_w005_2.pdf", sep="/"), width=20, height=18)
plot1b
# dev.off()

##################################################################################################
##################################################################################################
sessionInfo()
# R version 3.6.2 (2019-12-12)
# Platform: x86_64-apple-darwin15.6.0 (64-bit)
# Running under: OS X El Capitan 10.11.6

# Matrix products: default
# BLAS:   /Library/Frameworks/R.framework/Versions/3.6/Resources/lib/libRblas.0.dylib
# LAPACK: /Library/Frameworks/R.framework/Versions/3.6/Resources/lib/libRlapack.dylib

# locale:
# [1] en_US.UTF-8/en_US.UTF-8/en_US.UTF-8/C/en_US.UTF-8/en_US.UTF-8

# attached base packages:
# [1] stats     graphics  grDevices utils     datasets  methods   base     

# other attached packages:
# [1] forcats_0.4.0   stringr_1.4.0   dplyr_0.8.4     purrr_0.3.3     readr_1.3.1    
# [6] tidyr_1.0.2     tibble_2.1.3    ggplot2_3.2.1   tidyverse_1.3.0

# loaded via a namespace (and not attached):
 # [1] Rcpp_1.0.3       cellranger_1.1.0 pillar_1.4.3     compiler_3.6.2  
 # [5] dbplyr_1.4.2     tools_3.6.2      digest_0.6.23    jsonlite_1.6.1  
 # [9] lubridate_1.7.4  lifecycle_0.1.0  nlme_3.1-142     gtable_0.3.0    
# [13] lattice_0.20-38  pkgconfig_2.0.3  rlang_0.4.4      reprex_0.3.0    
# [17] cli_2.0.1        rstudioapi_0.10  DBI_1.1.0        haven_2.2.0     
# [21] withr_2.1.2      xml2_1.2.2       httr_1.4.1       fs_1.3.1        
# [25] generics_0.0.2   vctrs_0.2.2      hms_0.5.3        grid_3.6.2      
# [29] tidyselect_1.0.0 glue_1.3.1       R6_2.4.1         fansi_0.4.1     
# [33] readxl_1.3.1     farver_2.0.3     modelr_0.1.5     magrittr_1.5    
# [37] ellipsis_0.3.0   backports_1.1.5  scales_1.1.0     rvest_0.3.5     
# [41] assertthat_0.2.1 colorspace_1.4-1 labeling_0.3     stringi_1.4.5   
# [45] lazyeval_0.2.2   munsell_0.5.0    broom_0.5.4      crayon_1.3.4 
