############### Goedert et al - Frog Color: ###############
# Goedert, D., Clement, D., Calsbeek, R. Evolutionary trade-offs may interact with physiological constraints to maintain color variation. Ecological Monographs.
#################################################
########## Goedert et al - Rscript Plot Experiments ###########
## Created by: D. Goedert, version: 2020-05-14; double-checked 2020-07-14
# Experiments for dichotomous male choice of "light" vs "dark" colored females. Fig. 4
######################################################################
######################################################################
setwd("../../Codes-Experiments")
### Note: actually replace everything in between " " for the file path to the Dryad folder.

library(lubridate)
library(ggplot2)
######################################################################
twofemales<-read.csv("./Exp2females.csv")
str(twofemales)
# 'data.frame':	22 obs. of  15 variables:
 # $ Trial       : int  1 2 3 4 5 6 7 8 9 10 ...
 # $ Male        : Factor w/ 22 levels "CEM1","CEM8",..: 16 14 15 11 1 6 7 9 22 13 ...
 # $ FemaleD     : Factor w/ 19 levels "CEF1","CEF3",..: 13 13 14 9 18 18 10 15 17 5 ...
 # $ FemaleL     : Factor w/ 19 levels "CEF4","CWF2",..: 14 14 15 11 7 6 10 2 19 1 ...
 # $ SizeD       : num  55 55 54 54.6 51.2 51.2 59 50.6 56.4 55.2 ...
 # $ SizeL       : num  56.1 56.1 50.5 58.8 50.8 50.8 57.7 47.3 55.7 45.8 ...
 # $ MaleSize    : num  44.7 43.8 48 47 43.1 46.3 47.3 42.2 41.9 44.9 ...
 # $ TotalRight  : Factor w/ 22 levels "00:22.57","00:41.59",..: 20 6 7 12 19 14 4 10 11 8 ...
 # $ TotalLeft   : Factor w/ 22 levels "00:00.00","01:27.88",..: 4 7 19 3 8 14 18 9 6 16 ...
 # $ TotalLight  : Factor w/ 22 levels "00:23.03","00:32.82",..: 18 16 5 14 2 21 6 19 17 3 ...
 # $ TotalDark   : Factor w/ 20 levels "00:00.00","00:22.48",..: 7 1 17 4 19 1 14 2 5 18 ...
 # $ T_DarkLeft  : Factor w/ 17 levels "00:00.00","00:19.75",..: 1 1 16 4 9 1 10 3 2 14 ...
 # $ T_DarkRight : Factor w/ 18 levels "00:00.00","00:04.03",..: 9 1 12 2 17 1 8 1 6 14 ...
 # $ T_LightLeft : Factor w/ 20 levels "00:00.00","00:05.00",..: 11 14 7 5 1 18 9 15 13 3 ...
 # $ T_LightRight: Factor w/ 18 levels "00:00.00","00:18.03",..: 18 8 1 14 5 16 1 13 9 1 ... 

####################################
####################################
twof_forplot<-reshape(twofemales[,c(1,10,11)], varying=list(2:3), v.names=c("Time"), timevar="Color", direction="long")
str(twof_forplot)
# 'data.frame':	44 obs. of  4 variables:
 # $ Trial: int  1 2 3 4 5 6 7 8 9 10 ...
 # $ Color: int  1 1 1 1 1 1 1 1 1 1 ...
 # $ Time : Factor w/ 42 levels "00:23.03","00:32.82",..: 18 16 5 14 2 21 6 19 17 3 ...
 # $ id   : int  1 2 3 4 5 6 7 8 9 10 ...
 # - attr(*, "reshapeLong")=List of 4
  # ..$ varying:List of 1
  # .. ..$ : chr  "TotalLight" "TotalDark"
  # ..$ v.names: chr "Time"
  # ..$ idvar  : chr "id"
  # ..$ timevar: chr "Color"

twof_forplot$Time<-as.numeric(ms(twof_forplot$Time))
twof_forplot$Color<-as.factor(ifelse(twof_forplot$Color==1, "Light", "Dark"))
twof_forplot$Trial<-as.factor(twof_forplot$Trial)
#################################################
#################################################
# pdf("../Revisions/NewFigures_Output/Figure_Exp.pdf", width=6, height=6)
ggplot(twof_forplot, aes(y=Time, x=Color, group=Trial))+geom_point(size=3)+geom_line(size=1)+
	xlab("Female Color")+ylab("Association Time (seconds)")+
	theme_bw()+theme(panel.grid=element_blank(), axis.text.x=element_text(size=18), axis.text.y=element_text(size=18), text=element_text(size=20))
# dev.off()
#################################################
#################################################
# Legend: Total male association time with each of the two females simultaneously presented in a dichotomous choice test. Males were allowed to chose between a light-colored and a dark-colored female, based on human perception, for a total of 16 minutes (960 seconds); females were switched sides in the experimental arena halfway through.

# citation(package="lubridate")
# Garrett Grolemund, Hadley Wickham (2011). Dates and Times Made Easy with
  # lubridate. Journal of Statistical Software, 40(3), 1-25. URL
  # http://www.jstatsoft.org/v40/i03/.
#################################################
#################################################
sessionInfo()
# R version 3.6.2 (2019-12-12)
# Platform: x86_64-apple-darwin15.6.0 (64-bit)
# Running under: OS X El Capitan 10.11.6

# Matrix products: default
# BLAS:   /Library/Frameworks/R.framework/Versions/3.6/Resources/lib/libRblas.0.dylib
# LAPACK: /Library/Frameworks/R.framework/Versions/3.6/Resources/lib/libRlapack.dylib

# locale:
# [1] en_US.UTF-8/en_US.UTF-8/en_US.UTF-8/C/en_US.UTF-8/en_US.UTF-8

# attached base packages:
# [1] stats     graphics  grDevices utils     datasets  methods   base     

# other attached packages:
# [1] ggplot2_3.3.0   lubridate_1.7.8

# loaded via a namespace (and not attached):
 # [1] Rcpp_1.0.4.6     digest_0.6.25    withr_2.2.0      assertthat_0.2.1
 # [5] dplyr_0.8.5      crayon_1.3.4     grid_3.6.2       R6_2.4.1        
 # [9] lifecycle_0.2.0  gtable_0.3.0     magrittr_1.5     scales_1.1.0    
# [13] pillar_1.4.3     rlang_0.4.5      farver_2.0.3     vctrs_0.2.4     
# [17] generics_0.0.2   ellipsis_0.3.0   labeling_0.3     glue_1.4.0      
# [21] purrr_0.3.4      munsell_0.5.0    compiler_3.6.2   pkgconfig_2.0.3 
# [25] colorspace_1.4-1 tidyselect_1.0.0 tibble_3.0.1 