############### Goedert et al - Frog Color: ###############
# Goedert, D., Clement, D., Calsbeek, R. Evolutionary trade-offs may interact with physiological constraints to maintain color variation. Ecological Monographs.
#################################################
## Created by: D. Goedert, 2020-06-11
# double-checked: 2020-07-14
## Input: tables with color data from pictures
## Plots for color differences in age - Fig. 2
#################################################
############### Chapter 2- Frog Color: ###############
setwd("../../Codes-Pictures")
# setwd("drag and drop Codes-Pictures folder in here")
### Note: actually replace everything in between " " for the file path to the Dryad folder.
inputpath<-"./DataSets"
library(ggplot2)
library(tidyverse)
#################################################
recaps<-read.csv(paste(inputpath, "Color_Onlyrecap.csv", sep="/"))[,-1]
#################################################
str(recaps)
# 'data.frame':	11 obs. of  11 variables:
 # $ ID   : Factor w/ 11 levels "2016-GrM17","2016-GrM23",..: 1 2 3 4 5 6 7 8 9 10 ...
 # $ SVL16: num  44.4 45.3 48.2 47.5 50.1 44.8 49 51.2 50.3 59 ...
 # $ h16  : num  0.2412 0.2337 0.0908 0.0904 0.2776 ...
 # $ s16  : num  0.16 0.151 0.367 0.329 0.157 ...
 # $ v16  : num  0.222 0.224 0.393 0.37 0.221 ...
 # $ pc16 : num  -36 -34.5 21.1 14.6 -37.8 ...
 # $ SVL17: num  46.5 46.2 47.5 46.5 48 45.1 48.9 48.8 50.5 57.6 ...
 # $ h17  : num  0.098 0.1845 0.0875 0.0958 0.1966 ...
 # $ s17  : num  0.283 0.16 0.298 0.336 0.147 ...
 # $ v17  : num  0.326 0.226 0.391 0.368 0.217 ...
 # $ pc17 : num  0.966 -31.679 23.549 13.886 -35.524 ...
############################################################
(colnames(recaps)<-gsub("pc", "p", colnames(recaps)))
(colnames(recaps)<-gsub("SVL", "z", colnames(recaps)))
newrecaps<-recaps %>% 
	gather(key=What, value=Measure, -ID) %>%
	separate(2, c("variable", "year"), 1) %>%
	spread(variable, Measure)

colnames(newrecaps)
# [1] "ID"   "year" "h"    "p"    "s"    "v"    "z"   

colnames(newrecaps)[3:7]<-c("h", "pc1", "s","v", "svl")

str(newrecaps)
newrecaps$ID<-factor(newrecaps$ID)
newrecaps$year<-factor(paste("20", newrecaps$year, sep=""))
str(newrecaps)
# 'data.frame':	22 obs. of  7 variables:
 # $ ID  : Factor w/ 11 levels "2016-GrM17","2016-GrM23",..: 1 1 2 2 3 3 4 4 5 5 ...
 # $ year: Factor w/ 2 levels "2016","2017": 1 2 1 2 1 2 1 2 1 2 ...
 # $ h   : num  0.2412 0.098 0.2337 0.1845 0.0908 ...
 # $ pc1 : num  -36.004 0.966 -34.548 -31.679 21.088 ...
 # $ s   : num  0.16 0.283 0.151 0.16 0.367 ...
 # $ v   : num  0.222 0.326 0.224 0.226 0.393 ...
 # $ svl : num  44.4 46.5 45.3 46.2 48.2 47.5 47.5 46.5 50.1 48 ...
############################################################
############################################################
############################################################
############################################################
pp<-ggplot(data=newrecaps, aes(y=pc1, x=year))+
	geom_boxplot(color=rgb(0,0,0,alpha=0.3), outlier.shape=NA)+
	geom_point(size=3, color=hsv(newrecaps$h, newrecaps$s, 0.5))+
	geom_line(aes(group=ID), color=hsv(newrecaps$h, newrecaps$s, 0.5), size=0.5)+
	xlab("Year")+ylab("PC1")+
	theme_bw()+theme(panel.grid=element_blank(), axis.text.x=element_text(size=18), axis.text.y=element_text(size=18), text=element_text(size=20))
# pdf("../Revisions/NewFigures_Output/NewFig2_Pc1Year.pdf", height=4, width=4)	
pp
# dev.off()
############################################################
############################################################
############################################################
############################################################
############################################################
############################################################
############################################################
sessionInfo()
# R version 3.6.2 (2019-12-12)
# Platform: x86_64-apple-darwin15.6.0 (64-bit)
# Running under: OS X El Capitan 10.11.6

# Matrix products: default
# BLAS:   /Library/Frameworks/R.framework/Versions/3.6/Resources/lib/libRblas.0.dylib
# LAPACK: /Library/Frameworks/R.framework/Versions/3.6/Resources/lib/libRlapack.dylib

# locale:
# [1] en_US.UTF-8/en_US.UTF-8/en_US.UTF-8/C/en_US.UTF-8/en_US.UTF-8

# attached base packages:
# [1] stats     graphics  grDevices utils     datasets  methods  
# [7] base     

# other attached packages:
# [1] forcats_0.5.0   stringr_1.4.0   dplyr_0.8.5     purrr_0.3.4    
# [5] readr_1.3.1     tidyr_1.0.2     tibble_3.0.1    tidyverse_1.3.0
# [9] ggplot2_3.3.0  

# loaded via a namespace (and not attached):
 # [1] Rcpp_1.0.4.6     pillar_1.4.3     compiler_3.6.2   cellranger_1.1.0
 # [5] dbplyr_1.4.3     tools_3.6.2      digest_0.6.25    jsonlite_1.6.1  
 # [9] lubridate_1.7.8  lifecycle_0.2.0  nlme_3.1-147     gtable_0.3.0    
# [13] lattice_0.20-41  pkgconfig_2.0.3  rlang_0.4.5      reprex_0.3.0    
# [17] cli_2.0.2        rstudioapi_0.11  DBI_1.1.0        haven_2.2.0     
# [21] xml2_1.3.1       withr_2.2.0      httr_1.4.1       generics_0.0.2  
# [25] vctrs_0.2.4      fs_1.4.1         hms_0.5.3        grid_3.6.2      
# [29] tidyselect_1.0.0 glue_1.4.0       R6_2.4.1         fansi_0.4.1     
# [33] readxl_1.3.1     farver_2.0.3     modelr_0.1.6     magrittr_1.5    
# [37] backports_1.1.6  scales_1.1.0     ellipsis_0.3.0   rvest_0.3.5     
# [41] assertthat_0.2.1 colorspace_1.4-1 labeling_0.3     stringi_1.4.6   
# [45] munsell_0.5.0    broom_0.5.6      crayon_1.3.4  