############### Goedert et al - Frog Color: ###############
# Goedert, D., Clement, D., Calsbeek, R. Evolutionary trade-offs may interact with physiological constraints to maintain color variation. Ecological Monographs.
#################################################
## Script created by D. Goedert, double-checked 2020-07-14
## New versions for figures: Figure 1 and Figure SM2.2
#################################################
setwd("drag and drop Codes-Pictures folder in here")
### Note: actually replace everything in between " " for the file path to the Dryad folder.
inputpath<-"./DataSets"
outputpath<-"..../Revisions/NewFigures_Output"
#################################################
### Create Columns of interest:
data<-read.csv(paste(inputpath, "HSVdata_Pictures.csv", sep="/"))
#################################################
str(data)
# 'data.frame':	525 obs. of  7 variables:
 # $ X : Factor w/ 525 levels "2016-CEF1","2016-CEF2",..: 1 2 3 4 5 6 7 8 9 10 ...
 # $ Rs: num  71.1 70.2 103.2 59.2 110.5 ...
 # $ Gs: num  70.2 67.1 84.9 60.7 77.8 ...
 # $ Bs: num  60.1 56.5 66.7 51.1 58.8 ...
 # $ h : num  0.1536 0.1289 0.0828 0.1924 0.0612 ...
 # $ s : num  0.155 0.196 0.354 0.157 0.468 ...
 # $ v : num  0.279 0.275 0.405 0.238 0.433 ...
#################################################
colnames(data)[1]<-"FullID"
data$Year<-as.factor(gsub("-.*", "", data$FullID))
data$Pop<-as.factor(gsub("-", "", gsub('.{1}$', '', gsub("\\d", "", data$FullID))))
data$Sex<-as.factor(substr(gsub("\\d", "", data$FullID), nchar(gsub("\\d", "", data$FullID)), nchar(gsub("\\d", "", data$FullID))))
data$Pop<-as.factor(gsub("GR", "Gr", data$Pop))

str(data)
# 'data.frame':	525 obs. of  10 variables:
 # $ FullID: Factor w/ 525 levels "2016-CEF1","2016-CEF2",..: 1 2 3 4 5 6 7 8 9 10 ...
 # $ Rs    : num  71.1 70.2 103.2 59.2 110.5 ...
 # $ Gs    : num  70.2 67.1 84.9 60.7 77.8 ...
 # $ Bs    : num  60.1 56.5 66.7 51.1 58.8 ...
 # $ h     : num  0.1536 0.1289 0.0828 0.1924 0.0612 ...
 # $ s     : num  0.155 0.196 0.354 0.157 0.468 ...
 # $ v     : num  0.279 0.275 0.405 0.238 0.433 ...
 # $ Year  : Factor w/ 2 levels "2016","2017": 1 1 1 1 1 1 1 1 1 1 ...
 # $ Pop   : Factor w/ 10 levels "CE","CM","CW",..: 1 1 1 1 1 1 1 1 2 2 ...
 # $ Sex   : Factor w/ 2 levels "F","M": 1 1 1 1 1 1 2 2 1 2 ...
#################################################
library(ggplot2)
library(gridExtra)
library(ggfortify)
library(png)
library(grid)
#################################################
tapply(data$h, data$Sex, summary)
# $F
   # Min. 1st Qu.  Median    Mean 3rd Qu.    Max. 
# 0.05619 0.07102 0.08375 0.09774 0.10883 0.21634 

# $M
   # Min. 1st Qu.  Median    Mean 3rd Qu.    Max. 
# 0.05872 0.08977 0.10502 0.13374 0.16121 0.33228

femalemedian<-0.08375 ## female median - closed triangle shape=17
femalemean<-0.09774  ## females mean - open triangle  shape=2
malemedian<-0.10502 ## male median - closed circle shape=19
malemean<-0.13374 ## male mean - open circle shape=21

range(data$h)
# [1] 0.0561870 0.3322792

range(data$s)
# [1] 0.1121511 0.4862972

range(data$v)
# [1] 0.1987111 0.5664126

#################################################
pcargb<-prcomp(data[,c(2:4)])
# biplot(pcargb)
pcargb
# Standard deviations (1, .., p=3):
# [1] 22.7990383  4.1743873  0.9236258

# Rotation (n x k) = (3 x 3):
         # PC1        PC2        PC3
# Rs 0.8368012 -0.5192693  0.1735603
# Gs 0.4514379  0.4750222 -0.7553527
# Bs 0.3097865  0.7104317  0.6319170

summary(pcargb)
# Importance of components%s:
                          # PC1     PC2     PC3
# Standard deviation     22.799 4.17439 0.92363
# Proportion of Variance  0.966 0.03238 0.00159
# Cumulative Proportion   0.966 0.99841 1.00000

data$pc1<-pcargb$x[,1]
data$Sex<-factor(data$Sex, levels=c("M", "F"))
range(data$pc1)
# [1] -45.53489  82.91333

#################################################
############################################################
data[data$FullID %in% c("2016-RayM8","2017-RayM9", "2016-LGM1","2016-CEM7", "2016-CWM21", "2016-FarmM3", "2016-FarmM8", "2016-LGF2", "2016-GrF1","2016-RayF1", "2016-LandF1", "2017-CWF5", "2017-NCF3"),c(1,5)]

imagepath<-"../../Images/Presentation2"
dir(imagepath)

FarmM8<-readPNG(paste(imagepath, "Slide4-2016-FarmM8.png", sep="/"))
FarmM8<-rasterGrob(FarmM8, interpolate=TRUE)

LandF1<-readPNG(paste(imagepath, "Slide1-2016-LandF1.png", sep="/"))
LandF1<-rasterGrob(LandF1, interpolate=TRUE)

FarmM3<-readPNG(paste(imagepath, "Slide5-2016-FarmM3.png", sep="/"))
FarmM3<-rasterGrob(FarmM3, interpolate=TRUE)

RayM8<-readPNG(paste(imagepath, "Slide3-2016-RayM8.png", sep="/"))
RayM8<-rasterGrob(RayM8, interpolate=TRUE)

data[data$FullID %in% c( "2016-LandF1", "2016-FarmM3", "2016-RayM8","2016-FarmM8"),c(1,5)]
         # FullID          h
# 70  2016-FarmM3 0.15502279
# 75  2016-FarmM8 0.32292280
# 119 2016-LandF1 0.06805092
# 224  2016-RayM8 0.09323672

sexsymbol<-ifelse(data$Sex=="F", 17,21)
############################################################
dummy<-data.frame(hue=seq(0, 0.4, 0.0005), y1=rep(-1, length(seq(0, 0.4, 0.0005))))
#################################################
(distrib.sexes.hue2<-ggplot()+
	geom_density(data=data, aes(x=h, linetype=Sex, fill=Sex), alpha=0.1)+
	scale_fill_manual(values=c("white","black"))+
	geom_point(aes(x=malemean, y=0.6), shape=21, size=4)+ ## male mean - open circle
	geom_point(aes(x=femalemean, y=0.6), shape=2, size=4)+ ## females mean - open triangle
	geom_point(aes(x=malemedian, y=0.6), shape=19, size=4)+ ## male median - closed circle
		geom_point(aes(x=femalemedian, y=0.6), shape=17, size=4)+ ## female median - closed triangle
	annotate("text", x=0.35, y=18.5, label= "A", cex=7)+
	ylab("Number of Individuals")+xlab("Hue")+
	annotation_custom(FarmM8, xmin=0.32, xmax=0.35, ymin=-1, ymax=-5.6) +
	annotation_custom(LandF1, xmin=0.06, xmax=0.09, ymin=-1, ymax=-5.6) +
	annotation_custom(RayM8, xmin=0.11, xmax=0.14, ymin=-1, ymax=-5.6) +
	annotation_custom(FarmM3, xmin=0.17, xmax=0.20, ymin=-1, ymax=-5.6) +
	geom_point(data=dummy, aes(y=-0.65, x=hue), color=hsv(dummy$h, 0.7,0.7), size=6, alpha=0.8, shape=15)+
	theme_bw()+
	theme(legend.position="none", panel.grid.major = element_blank(), panel.grid.minor = element_blank(), axis.text.x=element_text(size=18), axis.text.y=element_text(size=18), text=element_text(size=20))+
	xlim(0, 0.35)+
	scale_y_continuous(limits=c(-4.5, 18.5), breaks=c(0,5,10,15)))

(pcplot2<-autoplot(pcargb, loadings=T, loadings.label=T,  size=2.5, shape=sexsymbol, colour=hsv(data$h, data$s, data$v), alpha=0.8)+theme_bw()+theme(legend.position="none", panel.grid.major = element_blank(), panel.grid.minor = element_blank(), axis.text.x=element_text(size=18), axis.text.y=element_text(size=18), text=element_text(size=20))+geom_vline(xintercept=0, linetype="dotted")+
	annotate("text", x=0.2, y=0.15, label= "B", cex=7)+
	geom_hline(yintercept=0, linetype="dotted"))

(pc.boxplot<-ggplot(data, aes(x=Sex, y=pc1))+geom_boxplot(outlier.color="white")+geom_jitter(alpha=0.4, size=2, width = 0.2, shape=sexsymbol)+
	ylim(-46, 83)+ylab("PC1")+
	annotate("text", x=2.5, y=79, label= "C", cex=7)+
	theme_bw()+theme(legend.position="none", panel.grid.major = element_blank(), panel.grid.minor = element_blank(), axis.text.x=element_text(size=18), axis.text.y=element_text(size=18), text=element_text(size=20)))

dummy.hplot<-data.frame(hue=seq(0.05, 0.34, 0.005), x1=rep(-57, length(seq(0.05, 0.34, 0.005))))
(pc.hplot<-ggplot(data, aes(y=h, x=pc1))+geom_point(shape=sexsymbol, size=2, color=hsv(data$h, data$s, data$v), alpha=0.5)+
	xlab("PC1")+ylab("Hue")+
	xlim(-57, 83)+
	geom_point(data=dummy.hplot, aes(y=hue, x=x1), color=hsv(dummy.hplot$hue, 0.7, 0.7), size=10, shape=15)+
	annotate("text", x=81, y=0.325, label= "D", cex=7)+
	theme_bw()+theme(legend.position="none", panel.grid.major = element_blank(), panel.grid.minor = element_blank(), axis.text.x=element_text(size=18), axis.text.y=element_text(size=18), text=element_text(size=20)))

#################################################
blank<-rectGrob(gp=gpar(col="white"))

 # pdf(paste(outputpath, "Fig1_metrics_v2.pdf", sep="/"), width=10.2, height=11.7)
grid.arrange(arrangeGrob(blank, distrib.sexes.hue2, blank, ncol=3, widths=c(0.2,9.8,0.2)),
arrangeGrob(arrangeGrob(blank, pcplot2, blank, nrow=3, heights=c(0.35, 5.5, 0.35)), blank,arrangeGrob(pc.boxplot, blank, pc.hplot,nrow=3, heights=c(3, 0.2, 3)), ncol=3, widths=c(6,0.2,4)), nrow=2, heights=c(5.5,6.2))
# dev.off()
#################################################
#################################################
#################################################
#################################################
(plot.s2<-ggplot(data, aes(x=h, y=s))+
	geom_point(shape=sexsymbol, size=2.5, color=hsv(data$h, data$s, data$v), alpha=0.4)+
	geom_point(data=dummy, aes(y=0.08, x=hue), color=hsv(dummy$h, 0.7,0.7), size=6, shape=15)+
	# geom_point(data=dummy.s2, aes(y=sat, x=y1), color=hsv(0.03, dummy.s2$sat, 0.7), size=6, shape=15)+
	ylab("")+xlab("")+
	annotate("text", x=0.35, y=0.49, label= "B", cex=7)+
	xlim(0.03, 0.35)+
	scale_y_continuous(limits=c(0.08, 0.49), breaks=c(0.1, 0.3, 0.5))+
	theme_bw()+theme(legend.position="none", panel.grid.major = element_blank(), panel.grid.minor = element_blank(), axis.text.x=element_text(size=18), axis.text.y=element_text(size=18), text=element_text(size=20)))

dummy.splot<-data.frame(sat=seq(0, 0.49, 0.005), x1=rep(-54, length(seq(0, 0.49, 0.005))))
pc.splot<-ggplot(data, aes(x=pc1, y=s))+geom_point(shape=sexsymbol, size=2, color=hsv(data$h, data$s, data$v), alpha=0.5)+
	xlab("")+ylab("Saturation")+
	xlim(-54, 83)+
	scale_y_continuous(limits=c(0.08, 0.49), breaks=c(0.1, 0.3, 0.5))+
	geom_point(data=dummy.splot, aes(y=sat, x=x1), color=hsv(0.03, dummy.splot$sat, 0.5), size=6, shape=15)+
	annotate("text", y=0.49, x=83, label= "A", cex=7)+
	theme_bw()+theme(legend.position="none", panel.grid.major = element_blank(), panel.grid.minor = element_blank(), axis.text.x=element_text(size=18), axis.text.y=element_text(size=18), text=element_text(size=20))

plot.b2<-ggplot(data, aes(x=h, y=v))+
	geom_point(shape=sexsymbol, size=2.5, color=hsv(data$h, data$s, data$v), alpha=0.4)+
	geom_point(data=dummy, aes(y=0.15, x=hue), color=hsv(dummy$h, 0.7,0.7), size=6, shape=15)+
	ylab("")+xlab("Hue")+
	annotate("text", x=0.35, y=0.6, label= "D", cex=7)+
	xlim(0.03, 0.35)+
	scale_y_continuous(limits=c(0.15, 0.6), breaks=c(0.2, 0.4, 0.6))+
	theme_bw()+theme(legend.position="none", panel.grid.major = element_blank(), panel.grid.minor = element_blank(), axis.text.x=element_text(size=18), axis.text.y=element_text(size=18), text=element_text(size=20))

dummy.vplot<-data.frame(bri=seq(0, 0.62, 0.005), x1=rep(-54, length(seq(0, 0.62, 0.005))))	
pc.vplot<-ggplot(data, aes(y=v, x=pc1))+geom_point(shape=sexsymbol, size=2, color=hsv(data$h, data$s, data$v), alpha=0.5)+
	xlab("PC1")+ylab("Brightness")+
	xlim(-54, 83)+
	geom_point(data=dummy.vplot, aes(y=bri, x=x1), color=hsv(0.03, 0.01, dummy.vplot$bri), size=6, shape=15)+
	scale_y_continuous(limits=c(0.15, 0.6), breaks=c(0.2, 0.4, 0.6))+
	annotate("text", x=83,y=0.6,  label= "C", cex=7)+
	theme_bw()+theme(legend.position="none", panel.grid.major = element_blank(), panel.grid.minor = element_blank(), axis.text.x=element_text(size=18), axis.text.y=element_text(size=18), text=element_text(size=20))
#################################################
# pdf(paste(outputpath, "FigS22_metrics_v2.pdf", sep="/"), width=8, height=8)
grid.arrange(arrangeGrob(pc.splot,plot.s2,  ncol=2, widths=c(4,4)), arrangeGrob(pc.vplot, plot.b2, ncol=2, widths=c(4,4)), nrow=2)
# dev.off()
############################################################
############################################################
## double-checked: 2020-07-14
sessionInfo()
# R version 3.6.2 (2019-12-12)
# Platform: x86_64-apple-darwin15.6.0 (64-bit)
# Running under: OS X El Capitan 10.11.6

# Matrix products: default
# BLAS:   /Library/Frameworks/R.framework/Versions/3.6/Resources/lib/libRblas.0.dylib
# LAPACK: /Library/Frameworks/R.framework/Versions/3.6/Resources/lib/libRlapack.dylib

# locale:
# [1] en_US.UTF-8/en_US.UTF-8/en_US.UTF-8/C/en_US.UTF-8/en_US.UTF-8

# attached base packages:
# [1] grid      stats     graphics  grDevices utils     datasets 
# [7] methods   base     

# other attached packages:
# [1] png_0.1-7       ggfortify_0.4.9 gridExtra_2.3   ggplot2_3.3.0  

# loaded via a namespace (and not attached):
 # [1] Rcpp_1.0.4.6     magrittr_1.5     tidyselect_1.0.0 munsell_0.5.0   
 # [5] colorspace_1.4-1 R6_2.4.1         rlang_0.4.5      stringr_1.4.0   
 # [9] dplyr_0.8.5      tools_3.6.2      gtable_0.3.0     withr_2.2.0     
# [13] ellipsis_0.3.0   digest_0.6.25    assertthat_0.2.1 tibble_3.0.1    
# [17] lifecycle_0.2.0  crayon_1.3.4     farver_2.0.3     purrr_0.3.4     
# [21] tidyr_1.0.2      vctrs_0.2.4      glue_1.4.0       labeling_0.3    
# [25] stringi_1.4.6    compiler_3.6.2   pillar_1.4.3     scales_1.1.0    
# [29] pkgconfig_2.0.3 